@@ -22,7 +22,6 @@
 #include "gnome-factory.h"
 
 #define MAX_TTD        64
-#define GOAD_MAGIC_FD 123
 
 #ifdef HAVE_DLFCN_H
 #    define SHLIB_DEPENDENCIES 1
@@ -48,6 +47,7 @@ extern CORBA_ORB _gnorba_gnome_orbit_orb; /* In orbitgtk.c */
 
 static GHashTable *living_shlib_servers = NULL, *living_by_filename = NULL;
 static const char *goad_activation_id = NULL;
+static int goad_fd = 0;
 
 static void goad_server_list_read(const char *filename,
 				  GArray *servinfo,
@@ -1107,14 +1107,11 @@ goad_server_activate_exe(GoadServer *sinfo,
     _exit(0); /* de-zombifier process, just exit */
   } else {
     char **args;
+    char fd_str [20];
     int i;
     struct sigaction sa;
 
     close(0);
-    if(iopipes[1] != GOAD_MAGIC_FD) {
-      dup2(iopipes[1], GOAD_MAGIC_FD);
-      close(iopipes[1]);
-    }
     
     setsid();
     memset(&sa, 0, sizeof(sa));
@@ -1124,11 +1121,14 @@ goad_server_activate_exe(GoadServer *sinfo,
     for(i = 0; args[i]; i++) /**/ ;
 
     if (sinfo->server_id) {
-      args = g_realloc(args, sizeof(char *) * (i+3));
+      args = g_realloc(args, sizeof(char *) * (i+5));
       args[i] = "--activate-goad-server";
       args[i+1] = sinfo->server_id;
-      args[i+2] = NULL;
-      i += 2;
+      args[i+2] = "--goad-fd";
+      g_snprintf (fd_str, sizeof (fd_str), "%d", iopipes [1]);
+      args[i+3] = fd_str;
+      args[i+4] = NULL;
+      i += 4;
     }
 
     if (params) {
@@ -1191,7 +1191,7 @@ goad_server_register(CORBA_Object name_server,
     FILE *iorout;
     struct sigaction oldaction, myaction;
 
-    iorout = fdopen(GOAD_MAGIC_FD, "a");
+    iorout = fdopen (goad_fd, "a");
     if(iorout) {
       memset(&myaction, '\0', sizeof(myaction));
       myaction.sa_handler = SIG_IGN;
@@ -1349,6 +1349,8 @@ goad_register_arguments(void)
 	static const struct poptOption options[] = {
 		{"activate-goad-server", '\0', POPT_ARG_STRING, &goad_activation_id, 0,
 		 N_("(Internal use only) GOAD server ID to activate"), "GOAD_ID"},
+		{"goad-fd", '\0', POPT_ARG_INT, &goad_fd, 0,
+		 N_("(Internal use only) GOAD file descriptor"), "GOAD_FD"},
 		{NULL, '\0', 0, NULL, 0}
 	};
 	
