@@ -170,7 +170,7 @@ update_utmp (UTMP *ut)
 	while ((ty = getttyent ()) != NULL)
 	{
 		++pos;
-		if (strncmp (ty->ty_name, ut->ut_line, sizeof (ut->ut_line)) == NULL)
+		if (strncmp (ty->ty_name, ut->ut_line, sizeof (ut->ut_line)) == 0)
 		{
 			lseek (fd, (off_t)(pos * sizeof(UTMP)), SEEK_SET);
 			write(fd, ut, sizeof(UTMP));
@@ -267,14 +267,15 @@ write_login_record (char *login_name, char *display_name, char *term_name, int u
 #endif
 
 	/* This shouldn't happen */
-	if (strncmp (pty, "/dev/", 5) == NULL)
+	if (strncmp (pty, "/dev/", 5) == 0)
 	    pty += 5;
 
 #if defined(HAVE_STRRCHR)
 	{
 		char *p;
 		
-		if ((p = strrchr (pty, '/')) != NULL) 
+		if (strncmp (pty, "pts", 3) &&
+		    (p = strrchr (pty, '/')) != NULL)
 			pty = p + 1;
 	}
 #endif
@@ -284,7 +285,9 @@ write_login_record (char *login_name, char *display_name, char *term_name, int u
 	ut->ut_id [0] = '\0';
 
 	/* BSD-like terminal name */
-	if (strncmp (pty, "pty", 3) == NULL || strncmp (pty, "tty", 3) == NULL) {
+	if (strncmp (pty, "pts", 3) == NULL ||
+	    strncmp (pty, "pty", 3) == NULL || 
+	    strncmp (pty, "tty", 3) == NULL) {
 		strncpy (ut->ut_id, pty+3, sizeof (ut->ut_id));
 	}
 	else {
